@@ -152,8 +152,9 @@ def _encode_iterable(iterable, f):
 	f.write(_TYPE_END)
 
 def _encode_mapping(mapping, f):
+	"""Encodes the mapping items in lexical order (spec)"""
 	f.write(_TYPE_DICT)
-	for key, value in mapping.items():
+	for key, value in sorted(mapping.items()):
 		_encode_buffer(key, f)
 		bencode(value, f)
 	f.write(_TYPE_END)
